@@ -4,6 +4,8 @@
 //     Full Text: https://github.com/fernandezfran/exma/blob/master/LICENSE
 #include "rdf.h"
 
+#include <math.h>
+
 void rdf_accumulate(const int natoms_c, const int natoms_i, const float *box,
                     const float *x_central, const float *x_interact,
                     const int pbc, const float dg, const float rmax,
@@ -28,21 +30,25 @@ void rdf_accumulate(const int natoms_c, const int natoms_i, const float *box,
     int ig;
 
     // i'm standing on the central atoms
-    for (int i = 0; i < natoms_c; i++) {
+    for (int i = 0; i < natoms_c; ++i) {
 
         // select the vector position of a particular one
-        for (int k = 0; k < 3; k++) { ri[k] = x_central[k * natoms_c + i]; }
+        for (int k = 0; k < 3; ++k) {
+            ri[k] = x_central[k * natoms_c + i];
+        }
 
         // computes the distance to all interacting atoms
-        for (int j = 0; j < natoms_i; j++) {
+        for (int j = 0; j < natoms_i; ++j) {
             rij2 = 0.0f;
-            for (int k = 0; k < 3; k++) {
+            for (int k = 0; k < 3; ++k) {
                 rj[k] = x_interact[k * natoms_i + j];
 
                 rij = rj[k] - ri[k];
                 if (pbc == 1) {
-                    while (rij > 0.5f * box[k]) rij -= box[k];
-                    while (rij < -0.5f * box[k]) rij += box[k];
+                    while (rij > 0.5f * box[k])
+                        rij -= box[k];
+                    while (rij < -0.5f * box[k])
+                        rij += box[k];
                 }
                 rij2 += rij * rij;
             }
@@ -51,9 +57,9 @@ void rdf_accumulate(const int natoms_c, const int natoms_i, const float *box,
             // accumulate in gr if the distance is less than the max and
             // greater than zero (this is required if the central and interact
             // type of atoms are the same)
-            if ((rij > 0) & (rij < rmax)) {
+            if ((rij < rmax) & (rij > 0)) {
                 ig = (int)(rij / dg);
-                gr[ig] += 1;
+                ++gr[ig];
             }
         }
     }
